# Harvard CS107 Final Project: SmartDiff

[![Build Status](https://travis-ci.com/SmartDiff/cs107-FinalProject.svg?branch=n-order)](https://travis-ci.com/SmartDiff/cs107-FinalProject)
[![codecov](https://codecov.io/gh/SmartDiff/cs107-FinalProject/branch/n-order/graph/badge.svg?token=9IKFVF8E1T)](https://codecov.io/gh/SmartDiff/cs107-FinalProject)

**Group 25**

Members: Bianca Cordazzo, Tianlei He, Xincheng Tan, Yilan Wang
